@@ -18,6 +18,6 @@ if {[module::register siteconfig "" "" "Site graphical configuration"]} {
 
 namespace eval ::html {
 	set css(a) { text-decoration: none; color: #FF0000; }
-	set css(.icon) { border: 0; }
+	set css(.icons) { border: 0; }
 	set css(.module_error) { text-alignment: center; color: #FF0000; }
 }
